@@ -1,7 +1,9 @@
-/* $Id: sm_sensor.c,v 1.1 2004/08/07 12:21:36 dijkstra Exp $ */
+/* $Id: sm_sensor.c,v 1.2 2005/10/18 19:58:12 dijkstra Exp $ */
 
 #include <stdlib.h>
 
+#include "sylimits.h"
+#include "data.h"
 #include "error.h"
 
 void
@@ -10,13 +12,13 @@ privinit_sensor()
     fatal("sensor module not available");
 }
 void
-init_sensor(char *s)
+init_sensor(struct stream *st)
 {
     fatal("sensor module not available");
 }
 
 int
-get_sensor(char *symon_buf, int maxlen, char *s)
+get_sensor(char *symon_buf, int maxlen, struct stream *st)
 {
     fatal("sensor module not available");
 
